\name{cokrigagem}
\alias{cokrigagem}

%- Also NEED an '\alias' for EACH other topic documented here.

\encoding{utf-8}

\title{Predição espacial de dados ALR transformados.}
\description{
  A função calcula o vetor de valores esperados preditos e a respectiva 
  matriz de covariância para os dados ALR transformados utilizando os resultados da distribuição  
  gaussiana multivariada.
}
\usage{
   cokrigagem(esti.par, dim.gride, locations, dados.comp)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{esti.par}{Vetor das estimativas dos parâmetros calculados através da função \code{mec}.}
  \item{dim.gride}{Vetor numérico com o valor da dimensão da grade de predição.}
  \item{locations}{Data frame contendo as coordenadas das localizações de predição.}
  \item{dados.comp}{Um objeto da classe geoComp.}
}
\details{
  A predição espacial de \eqn{Y_0} em localizações não amostradas \eqn{x_0=(x_{10},x_{20},...,
  x_{n_{2}0})} é realizada segundo resultados da distribuição gaussiana multivariada.
  O vetor de valores esperados nas \eqn{n_{2}} localizações é dado por
  \deqn{\mu_{Y_0|Y}=\mu_{Y_0}+\Sigma_{Y_0 Y}\Sigma_{YY}^{-1}(Y-\mu_Y)}
  e a matriz de covariância é dada por
   \deqn{\Sigma_{Y_0|Y}=\Sigma_{Y_0 Y_0}-\Sigma_{Y_0 Y}\Sigma_{YY}^{-1}\Sigma_{YY_0}.}
}
\value{
  A função retorna uma lista com os seguintes resultados:
  \item{comp1 }{vetor dos valores esperados preditos.}
  \item{comp2 }{matriz de covariância predita.}
}
\references{ 
    Diggle, P. J., and Ribeiro,Jr., P. J., (2007). \emph{Model-based geostatistics}. 
    Springer Series in Statistics, USA.

    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.
}
\author{
  Wagner Hugo Bonat \email{wagner@leg.ufpr.br}, \cr
  Ana Beatriz Tozzo Martins \email{abtmartins@uem.br}, \cr
  Paulo Justiniano Ribeiro Jr. \email{paulojus@leg.ufpr.br}.
}
%\note{ ~~further notes~~ 
%
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{
### carregando pacotes
require(geoComp)
require(MASS)
require(statmod)
require(geoR)
### Carregando os dados
data(pivo)
### Selecionando as colunas referentes aos componentes 1, 2 e 3, 
### Coordenada X e coordenada Y
dados <- pivo[,c(6,7,8,1,2)]
### Transformando o objeto "dados" para a classe geoComp
dados <- as.geoComp(dados)
### Construindo a borda da área de predição
bor <- cbind(c(0,seq(0,200,l=100),0),c(0,sqrt(200^2-seq(0,200,l=100)^2),0)) 
### Construindo uma grade de predição
gr <- pred_grid(bor, by=70)
### Ajustando o modelo
estima <- mec(dados)
### Obtendo os valores preditos no R^2
md.cov.ck <- cokrigagem(estima[[1]]$Estimativas, loc=gr,dados.comp=dados)
}
\keyword{multivariate}
\keyword{spatial}
