\name{infbayes}
\alias{infbayes}

%- Also NEED an '\alias' for EACH other topic documented here.

\encoding{utf-8}

\title{Ajuste do modelo por inferência bayesiana para dados composicionais.}
\description{
    A função ajusta um modelo para dados composicionais por métodos bayesianos.
Utiliza-se o algoritmo Metropolis-Hastings, função MCMCmetrop1R do pacote \pkg{MCMCpack} para a estimação dos parametros \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2}, \eqn{\phi} e \eqn{\rho}.
}
\usage{
   infbayes(dados, tune, queima, salto, nsim, verbose = TRUE, mediahiper)
}
\arguments{
  \item{dados}{Objeto da classe \code{geoComp}.}
  \item{tune}{Vetor com 5 elementos iguais aos limites de variâncias para \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2}, \eqn{\phi} e \eqn{\rho}.}
  \item{queima}{Vetor numérico correspondente ao número de simulações a serem descartadas como período de aquecimento da cadeia.}
  \item{salto}{Vetor numérico que indica de quanto em quanto os dados são armazenados.}
  \item{nsim}{Vetor numérico correspondente ao número de simulações.}
  \item{verbose}{Lógico, indicando se a mensagem de que a log-verossimilhança está sendo otimizada deve aparecer na tela (`verbose = TRUE') ou não (`verbose = FALSE'). O default é `TRUE'.}
  \item{mediahiper}{Vetor com 8 elementos correspondentes aos valores dos hiperparâmetros das prioris log-normais para \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2} e Gama para \eqn{\phi}. Os três primeiros correspondem as médias para \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2}, o quarto é o hiperparâmetro \eqn{\alpha} para \eqn{\phi}, os três seguintes correspondem aos desvios-padrão para \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2} e o último, o hiperparâmetro \eqn{\beta} para \eqn{\phi}. O default é (log(24), log(0.63), log(0.59), 66, 0.3, 0.3, 0.3, 1).}
}
\details{
   A distribuição a posteriori marginal para \eqn{\b{$\mu$}|\sigma_1^2,\theta^{*},\b{$Y$}} é      \cr
   \deqn{[\mu|\sigma_1^2,\theta^{*},\b{$Y$}] \sim N(\hat{\b{$\mu$}};\sigma_1^2 (D'V^{-1}D)^{-1}),}\cr
   onde \eqn{\hat{\b{$\mu$}}} é dado em \code{mec.R} e para \eqn{\sigma_1^2|\theta^{*},\b{$Y$}} é \cr
   \deqn{[ \sigma_1^2|\theta^{*},\b{$Y$}] \sim \chi_{Sinv}^2 (n-n_{\b{$\mu$}};S^2 ),}             \cr
   onde \eqn{\chi_{Sinv}^2} é a distribuição qui-quadrado escalonada inversa e            \cr
   \deqn{S^2=\frac{n}{n-n_{\b{$\mu$}}}\hat{\hat{\sigma}}_1^2=\frac{(\b{$Y$}-D\hat{\b{$\mu$}})'V^{-1}(\b{$Y$}-D\hat{\b{$\mu$}})}{n-n_{\b{$\mu$}}}.}

}
\value{
  A função retorna uma lista com os seguintes elementos:
  \item{comp1 }{data frame contendo os valores a posteriori de \eqn{\beta_1}, \eqn{\beta_2} e \eqn{\sigma_1}.}
  \item{comp2 }{data frame contendo os valores a posteriori de \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2}, \eqn{\phi} e \eqn{\rho}.}
}
\references{ 
    Diggle, P. J., and Ribeiro,Jr., P. J., (2007). \emph{Model-based geostatistics}. 
    Springer Series in Statistics, USA.

    Gamerman, D., and Lopes, H. F., (2006). \emph{Markov chain Monte Carlo: stochastic simulation
    for Bayesian inference}. 2.ed. Chapman and Hall/CRC, Londres.
 
    Gelman, A., and Carlin, J. B., and Stern, H. S., and Rubin, D. B., (2003).
    \emph{Bayesian Data Analysis}. 2.ed. Chapman and Hall, Boca Raton.

    Gilks, W. R., and Richardson, S., and Spiegelhalter, D. J., (1996).
    \emph{Markov Chain Monte Carlo in Practice}. Chapman and Hall, London.

    Gill, J., (2000). \emph{Bayesian Methods For The Social And Behavioral Sciences}. Chapman and Hall, London.

    Lee, P. M., (2004). \emph{Bayesian Statistics}. 3.ed. Arnold, New York.

    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.

    Ribeiro, Jr, P. J. and Diggle, P. J., (1999). \emph{Bayesian inference in Gaussian model-based geostatistics}.
    ST-99-08., Dept. of Maths and Stats, Lancaster University, Lancaster, Techinical Report.

    Rue, H., and Held, L., (2005). \emph{Gaussian Markov Random Fields}. Chapman and Hall, Boca Raton.
}
\author{
  Wagner Hugo Bonat \email{wagner@leg.ufpr.br}, \cr
  Ana Beatriz Tozzo Martins \email{abtmartins@uem.br}, \cr
  Paulo Justiniano Ribeiro Jr. \email{paulojus@leg.ufpr.br}.
}
%\note{ ~~further notes~~ 
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{
### Carregando pacotes
require(geoR)
require(geoComp)
require(MCMCpack)
require(MASS)
### Carregando os dados
data(pivo)
### Selecionando as colunas referentes aos componentes 1, 2 e 3, 
### Coordenada X e coordenada Y
dados <- pivo[,c(6,7,8,1,2)]
### Transformando o objeto "dados" para a classe geoComp
dados <- as.geoComp(dados)
### Fazendo o ajuste do modelo por métodos bayesianos
estima.bayes <- infbayes(dados,tune=c(0.5,0.5,0.5,0.5,0.5),queima=1,salto=5,
                         nsim=20,mediahiper=c())
}
\keyword{models}
\keyword{multivariate}
\keyword{spatial}
\keyword{optimize}
