\name{logarit.vero}
\alias{logarit.vero}

%- Also NEED an '\alias' for EACH other topic documented here.

\encoding{utf-8}

\title{Log-Verossimilhança.}
\description{
  A função calcula a log-verossimilhança do modelo.
}
\usage{
  logarit.vero(theta1, dados.comp, print.pars = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{theta1}{Vetor com valores para os parâmetros \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2}, \eqn{\phi} e \eqn{\rho}.}
  \item{dados.comp}{Objeto da classe geoComp.}
  \item{print.pars}{Lógico. Se `TRUE', indica que os parâmetros e o valor do negativo da log-verossimilhança (a menos de uma constante) são printadas na tela cada vez que a função a ser minimizada for chamada.}
}
\details{
   A função de verossimilhança do modelo é
   \deqn{L(\theta;\b{$Y$})=(2\pi)^{-n/2} |\Sigma|^{-1/2} exp\{-\frac{1}{2}(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}})'\Sigma^{-1}(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}})\},}
   com vetor de parâmetros \eqn{\theta=(\b{$\mu$},\sigma_1,\sigma_2,\tau_1,\tau_2,\phi,\rho).}
   A função de log-verossimilhança com a reparametrização \eqn{\eta=\frac{\sigma_2}{\sigma_1},} \eqn{\nu_1=\frac{\tau_1}{\sigma_1}} e \eqn{\nu_2=\frac{\tau_2}{\sigma_1}} é
   \deqn{l(\theta;\b{$Y$})=-\frac{1}{2}(n\,ln(2\pi)+2n ln(\sigma_1)+ln(|V|)+\frac{1}{\sigma_1^2}Qe).}
   em que \eqn{Qe=(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}})'V^{-1}(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}})}. Ao substituir as estimativas de máxima verossimilhança,
   \deqn{\hat{\b{$\mu$}} = (D'V^{-1}D)^{-1}(D'V^{-1}\b{$Y$}) \hspace{0.6cm} e \hspace{0.6cm}\hat{\sigma}_1 = \sqrt{\hat{Q}e/n}.} 
   na função de verossimilhança tem-se a função de log-verossimilhança concentrada
\deqn{l(\b{$\theta$}^*;\b{$Y$})=-\frac{1}{2} [ ln(|\textbf{V}|) + n(ln(2\pi) + ln(\hat{Qe}) - ln(n)+ 1) ]}
   com \eqn{\theta^{*}=(\eta,\nu_1,\nu_2,\phi,\rho).}
}
\value{
  A função retorna um vetor numérico contendo o negativo do valor da log-verossimilhança do modelo.
}
\references{
    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.
}
\author{
  Wagner Hugo Bonat \email{wagner@leg.ufpr.br}, \cr
  Ana Beatriz Tozzo Martins \email{abtmartins@uem.br}, \cr
  Paulo Justiniano Ribeiro Jr. \email{paulojus@leg.ufpr.br}.
}
%\note{ ~~further notes~~ 
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{
### Carregando pacote
require(geoComp)
### Carregando dados
data(pivo)
### Selecionando dados
dados <- pivo[1:15,c(6,7,8,1,2)]
### Transformando o objeto "dados" para a classe geoComp
dados.comp <- as.geoComp(dados)
y1 <- dados.comp[[1]]$Y1
y2 <- dados.comp[[1]]$Y2
coords <- dados.comp[[3]]
### Calculando os valores iniciais 
mu1 <- mean(y1)
mu2 <- mean(y2)
var_y1 <- var(y1)
s1 <- var_y1/2
tau1 <- s1
var_y2 <- var(y2)
s2 <- var_y2/2
tau2 <- s2
dim <- range(dist(coords))
phi <- dim[1] + 0.2*(dim[2]-dim[1])  
rho <- cor(y1,y2)
y <- dados.comp[[2]][[1]]
### Reparametrizando
eta <- s2/s1
nu1 <- tau1/s1
nu2 <- tau2/s1
theta1 <- c(eta,nu1,nu2,phi,rho)
### Calculando a matriz de covariância 
V <- monta.V(theta1,dados.comp)
### Calculando o logaritmo da vero. para o theta1 inicial
ll <- logarit.vero(theta1,dados.comp)
}
\keyword{math}
\keyword{multivariate}
