\name{mec}
\alias{mec}

%- Also NEED an '\alias' for EACH other topic documented here.

\encoding{utf-8}

\title{Ajuste de modelo baseado em verossimilhança para dados composicionais espaciais.}
\description{
   A função ajusta um modelo espacial baseado em verossimilhança para dados composicionais.
}
\usage{
  mec(dados.comp, metodo = "L-BFGS-B",print.pars = FALSE, alpha = 0.975)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{dados.comp}{Objeto da classe geoComp.}
  \item{metodo}{Algoritmo utilizado na função optim. Outras opções: \dQuote{Nelder-Mead}, \dQuote{CG} e \dQuote{BFGS}.}
  \item{print.pars}{Lógico. Se `TRUE', indica que os parâmetros e o valor do negativo da log-verossimilhança (a menos de uma constante) são printadas na tela cada vez que a função a ser minimizada for chamada. O default é `FALSE'}
  \item{alpha}{Vetor numérico correspondente ao nível crítico utilizado no cálculo do intervalo de confiança.}
}
\details{
  Esta função estima os parâmetros do modelo de campo aleatório gaussiano
  especificado como:
  \deqn{Y_1(x) = \mu_1(x) + S_1(x) + Z_1(x)}{Y_1(x) = mu_1(x) + S_1(x) + Z_1(x)}
  \deqn{Y_2(x) = \mu_2(x) + S_2(x) + Z_2(x)}{Y_2(x) = mu_2(x) + S_2(x) + Z_2(x)}
  onde
  \itemize{
    \item \eqn{x} define uma localização espacial. Geralmente coordenadas Euclidianas
    num plano. 
    \item \eqn{Y_1} e \eqn{Y_2} são as variáveis observadas na localização \eqn{x}
     e constituem o vetor \eqn{Y}.
    \item \eqn{\b{$\mu$}(x) = D\b{$\mu$}}{mu(x) = D \%*\% mu} é o componente média 
    do modelo (tendência). 
    \item \eqn{S(x)} é um processo gaussiano estacionário com variância \eqn{\sigma^2}
    (patamar) e uma função de correlação exponencial com parâmetro de alcance \eqn{\phi}. 
    \item \eqn{Z(x)} é o efeito composicional.
  }
  A função de verossimilhança do modelo é
  \deqn{L(\theta;\b{$Y$})=(2\pi)^{-n/2} |\Sigma|^{-1/2} exp\{-\frac{1}{2}(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}})'\Sigma^{-1}(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}})\}.}
   Fazendo-se a reparametrização: \eqn{\eta=\frac{\sigma_2}{\sigma_1};} 
                                   \eqn{\nu_1=\frac{\tau_1}{\sigma_1};} 
                                   \eqn{\nu_2=\frac{\tau_2}{\sigma_1},}
   pode-se escrever \deqn{\Sigma=\sigma_1^2 R+\tau_1^2 I_b=\sigma_1^2 V,}
   e a função de log-verossimilhança reparametrizada é dada por
   \deqn{l(\theta;\b{$Y$})=-(1/2)(n\,ln(2\pi)+2n ln(\sigma_1)+ln(|V|)+(1/\sigma_1^2)Qe).}
   onde \eqn{Qe=(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}})'V^{-1}(\b{$Y$}-\b{$\mu$}_{\scriptsize \b{$Y$}}).} Os estimadores de máxima verossimilhança são:\cr
   \deqn{\hat{\b{$\mu$}} = (D'V^{-1}D)^{-1}(D'V^{-1}\b{$Y$})\hspace{0.6cm} e \hspace{0.6cm}\hat{\sigma}_1 = \sqrt{\hat{Q}e/n}.}\cr
   As variâncias dos estimadores obtidos pelo método Delta são:
   \deqn{Var(\hat{\b{$\mu$}})= \hat{\sigma}_1^2 (D'\hat{V}^{-1}D)^{-1}\hspace{0.6cm} e \hspace{0.6cm} Var(\hat{\sigma}_1) = (\hat{\sigma}_1^3/(3\hat{Q}e-n \hat{\sigma}_1).}\cr
   As estimativas para os parâmetros \eqn{\sigma_2}, \eqn{\tau_1}, \eqn{\tau_2}, \eqn{\phi} e \eqn{\rho} são obtidas numericamente.
}
\value{data.frame contendo
  A função retorna uma lista com os dois seguintes objetos:
  \item{comp1 }{data.frame contendo as estimativas dos parâmetros, erros-padrão e intervalos de 95\% de confiança via método Delta.}
  \item{comp2 }{data.frame contendo o negativo da log-verossimilhança inicial e otimizada.}
}
\references{ 
    Azzalini, A., (1996). \emph{Statistical Inference Based on the Likelihood}. Chapman and Hall, London.
  
    Cox, D. R., and Hinkley, D. V., (1974). \emph{Theoretical Statistics}. Chapman and Hall, London.
 
    DeGroot, M. H.and Schervish, M. J.(2002). \emph{Probability and Statistics}. 3.ed., Addison Wesley, Boston.

    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.

    Pawitan, Y., (2001). \emph{In All Likelihood}. Oxford University Press, Inc, New York.
}
\author{
  Wagner Hugo Bonat \email{wagner@leg.ufpr.br}, \cr
  Ana Beatriz Tozzo Martins \email{abtmartins@uem.br}, \cr
  Paulo Justiniano Ribeiro Jr. \email{paulojus@leg.ufpr.br}.
}
%\note{ ~~further notes~~ 
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{\code{\link[geoR]{likfit}} }
\examples{
### Carregando pacote
require(geoComp)
### Carregando os dados
data(pivo)
### Selecionando as colunas referentes aos componentes 1, 2 e 3, 
### Coordenada X e coordenada Y
dados <- pivo[,c(6,7,8,1,2)]
### Transformando o objeto "dados" para a classe geoComp
dados <- as.geoComp(dados)
### Fazendo o ajuste do modelo
estima <- mec(dados)
}
\keyword{models}
\keyword{multivariate}
\keyword{spatial}
\keyword{optimize}
