\name{pivo}
\alias{pivo}
\docType{data}

\encoding{utf-8}

\title{Propriedades do solo irrigado por um sistema de pivo.}

\description{Propriedades do solo irrigado por um sistema de pivo.}

\usage{data(pivo)}
\format{
  Um data frame contendo 76 observações das seguintes 8 variáveis:
  \describe{
    \item{\code{X}}{ um vetor numérico com as coordenadas X das observações.}
    \item{\code{Y}}{ um vetor numérico com as coordenadas Y das observações.}
    \item{\code{DenSoil}}{ numérico, densidade do solo \eqn{g/cm^3}.}
    \item{\code{DenPar}}{ numérico, densidade da partícula (\%).}
    \item{\code{PoroTot}}{ numérico, porosidade total (\%).}
    \item{\code{Areia}}{ numérico, fração do conteúdo de areia (\%).}
    \item{\code{Silte}}{ numérico, fração do conteúdo de silte (\%).}
    \item{\code{Argila}}{ numérico, fração do conteúdo de argila (\%).}}
}
\details{
      A densidade do solo é definida como:
      \deqn{DenSoil=\frac{m_{ss}}{V_T}} 
      onde \eqn{m_{ss}} é a massa de solo seco e \eqn{V_T} é o volume total.
      \deqn{V_T=V_s+V_p,} 
      sendo \eqn{V_s} o volume de sólidos e \eqn{V_p} o volume de poros.
      A densidade da partícula é definida como:
      \deqn{DenPar=\frac{m_{ss}}{V_s}}
      e a porosidade total é como: 
      \deqn{PoroTot=\frac{V_p}{V_T}.}
}
\source{
    Gonçalves, A. C. A., (1997). \emph{Variabilidade espacial de propriedades físicas do solo para fins 
    de manejo da irrigação}. 119p., Tese (Doutorado em Agronomia) - Escola Superior de Agricultura 
    "Luiz de Queiroz", Universidade de São Paulo, Piracicaba.
}
\references{
    Gonçalves, A. C. A., and Folegatti, M. V., and Mata, J. D. V., (2001). Análises exploratória e geoestatística
    da variabilidade de propriedades físicas de um Argissolo Vermelho. \emph{Acta Scientiarum} \bold{23}, n. 5, 1149-1157. 

    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.
}
\examples{
### Carregando pacotes 
require(compositions)
require(geoComp)
### Lendo um arquivos de dados 
data(pivo)
### Selecionado os dados composicionais 
dados <- pivo[,c(6,7,8)]
### Escala representada na classe acomp onde os dados são analisados 
### na geometria relativa
comp <-  acomp(dados)
### Construindo um diagrama ternário
plot(comp)
### Incluindo o centro da distribuição
plot(mean(comp),add=TRUE,pch=20,col='red')
### Incluindo as regiões 2 e 4-desvios-padrão de confiança
ellipses(mean(comp),var(comp),col='red',r=2)
ellipses(mean(comp),var(comp),col='red',r=4)
}
\keyword{datasets}
