\name{posteriori}
\alias{posteriori}

%- Also NEED an '\alias' for EACH other topic documented here.

\encoding{utf-8}

\title{Posteriori do modelo bayesiano para dados composicionais espaciais.}
\description{
  A função calcula a posteriori do modelo geoestatístico bivariado para dados composicionais.
}
\usage{
   posteriori(theta1, dados.comp, mediahiper, print.pars = TRUE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{theta1}{Vetor cujos elementos são os valores para os parâmetros \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2}, \eqn{\phi} e \eqn{\rho}.}
  \item{dados.comp}{Objeto da classe geoComp.}
  \item{mediahiper}{Vetor com 8 elementos correspondentes aos valores dos hiperparâmetros das prioris log-normais para \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2} e Gama para \eqn{\phi}. Os três primeiros correspondem as médias para \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2}, o quarto é o hiperparâmetro \eqn{\alpha} para \eqn{\phi}, os três seguintes correspondem aos desvios-padrão para \eqn{\eta}, \eqn{\nu_1}, \eqn{\nu_2} e o último, o hiperparâmetro \eqn{\beta} para \eqn{\phi}. O default é (log(24), log(0.63), log(0.59), 66, 0.3, 0.3, 0.3, 1).}
  \item{print.pars}{Lógico, indicando se a função retorna o vetor \code{theta1} e o valor da posteriori (`print.pars = TRUE') ou apenas o valor da posteriori (`print.pars = FALSE').}
}
\details{
  posteriori=vero x priori(\eqn{\eta}) x priori(\eqn{\nu_1}) x priori(\eqn{\nu_2}) x priori(\eqn{\phi}) x 1
}
\value{
  A função retorna o valor da posteriori e o vetor \code{theta1}.
}
\references{
    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.
}
\author{
  Wagner Hugo Bonat \email{wagner@leg.ufpr.br}, \cr
  Ana Beatriz Tozzo Martins \email{abtmartins@uem.br}, \cr
  Paulo Justiniano Ribeiro Jr. \email{paulojus@leg.ufpr.br}.
}
%\note{ ~~further notes~~ 
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{
### Carregando pacotes
require(geoComp)
require(MCMCpack)
require(MASS)
### Carregando os dados
data(pivo)
### Selecionando as colunas referentes aos componentes 1, 2 e 3, 
### Coordenada X e coordenada Y
dados <- pivo[,c(6,7,8,1,2)]
### Transformando o objeto "dados" para a classe geoComp
dados <- as.geoComp(dados)
### Calculando os valores iniciais 
y1 <- dados[[1]]$Y1
y2 <- dados[[1]]$Y2
coords <- dados[[3]]
mu1 <- mean(y1)
mu2 <- mean(y2)
var_y1 <- var(y1)
s1 <- var_y1/2
tau1 <- s1
var_y2 <- var(y2)
s2 <- var_y2/2
tau2 <- s2
dim <- range(dist(coords))
phi <- dim[1] + 0.2*(dim[2]-dim[1])  
rho <- cor(y1,y2)
eta <- s2/s1
nu1 <- tau1/s1
nu2 <- tau2/s1
theta1 <- c(eta,nu1,nu2,phi,rho)
### Calculando a posteriori
posteriori(theta1,dados.comp=dados,mediahiper=c(),print.pars=TRUE)
}
\keyword{math}
\keyword{spatial}
