\name{volta.cokri}
\alias{volta.cokri}

%- Also NEED an '\alias' for EACH other topic documented here.

\encoding{utf-8}

\title{Transformação de volta para o simplex por simulação.}
\description{
  A função transforma o vetor de valores esperados e matriz de covariância preditos no \eqn{R^2} para o 
  simplex utilizando simulação.  
}
\usage{
  volta.cokri(mat.cokri, num.simu, retorna.tudo = FALSE, int.conf = 0.95)
}
\arguments{
  \item{mat.cokri}{Uma lista cujo primeiro elemento contém o vetor de valores esperados preditos e segundo elemento contém a matriz de covariância predita.}
  \item{num.simu}{Vetor numérico correspondente ao número de simulações.}
  \item{retorna.tudo}{Lógico, indicando se a função deve retornar, separadamente, os valores esperados preditos por simulação para cada componente (`retorna.tudo = TRUE') ou a função deve calcular as médias do número de simulações para cada localização e para cada componente os intervalos de 95\% de confiança (`retorna.tudo = FALSE').}
  \item{int.conf}{Vetor numérico correspondente ao nível de confiança.}
}
\details{
  Os dados são simulados de uma distribuição gaussiana multivariada com vetor de 
  médias e matriz de covariância dados em \code{mat.cokri} e em seguida é aplicada 
  a função \code{agl} transformando-os em composições. 
}
\value{
  Se retorna.tudo=TRUE, a função retorna uma lista com os três primeiros elementos a seguir e, se retorna.tudo=FALSE, a função retorna uma lista com os dois últimos:
  \item{comp1 }{valores esperados preditos simulados para cada localização de predição do componente 1.}
  \item{comp2 }{valores esperados preditos simulados para cada localização de predição do componente 2.}
  \item{comp3 }{valores esperados preditos simulados para cada localização de predição do componente 3.}
  \item{comp4 }{um data frame com 3 colunas correspondentes as médias do número de simulações para cada localização e para cada componente.}
  \item{comp5 }{um data frame contendo os limites dos intervalos de confiança.}
}
\references{
    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.

    Diggle, P. J., and Ribeiro,Jr., P. J., (2007). \emph{Model-based geostatistics}. 
    Springer Series in Statistics, USA.
}
\author{
  Wagner Hugo Bonat \email{wagner@leg.ufpr.br}, \cr
  Ana Beatriz Tozzo Martins \email{abtmartins@uem.br}, \cr
  Paulo Justiniano Ribeiro Jr. \email{paulojus@leg.ufpr.br}.
}
%\note{ ~~further notes~~ 
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{
### carregando pacotes
require(geoComp)
require(MASS)
require(geoR)
### Carregando os dados
data(pivo)
### Selecionando as colunas referentes aos componentes 1, 2 e 3, 
### Coordenada X e Coordenada Y
dados <- pivo[,c(6,7,8,1,2)]
### Transformando o objeto "dados" para a classe geoComp
dados <- as.geoComp(dados)
### Construindo a borda da área de predição
bor <- cbind(c(0,seq(0,200,l=100),0),c(0,sqrt(200^2-seq(0,200,l=100)^2),0)) 
### Construindo uma grade de predição
gr <- pred_grid(bor, by=70)
### Ajustando o modelo
estima <- mec(dados)
### Obtendo os valores preditos no R^2
md.cov.ck <- cokrigagem(estima[[1]]$Estimativas, loc=gr,dados.comp=dados)
### Obtendo os valores preditos no simplex por simulação
preditos.simu <- volta.cokri(md.cov.ck,num.simu=10,int.conf=0.95)
preditos.simu <- data.frame(preditos.simu[[1]])
preditos.simu.ic <- data.frame(preditos.simu[[2]])
}
\keyword{multivariate}
\keyword{spatial}
