\name{volta.quad}
\alias{volta.quad}

%- Also NEED an '\alias' for EACH other topic documented here.

\encoding{utf-8}

\title{Transformação de volta para o simplex por quadratura de Gauss-Hermite.}
\description{
  A função transforma o vetor de valores esperados e matriz de covariância preditos no \eqn{R^2} para o 
  simplex utilizando quadratura gaussiana.  
}
\usage{
  volta.quad(med.cov, n.pontos = 7, Variancia = FALSE)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{med.cov}{Uma lista cujo primeiro elemento contém o vetor de valores esperados preditos e segundo elemento contém a matriz de covariância predita.}
  \item{n.pontos}{Vetor numérico correspondente a ordem da quadratura de Gauss-Hermite.}
  \item{Variancia}{Lógico, indicando se a função não deve calcular a matriz de covariância no espaço amostral simplex  (`Variancia = FALSE') ou se deve calcular (`Variancia = TRUEf') }
}
\details{
   O objetivo é calcular para cada localização uma estimativa de 
   \deqn{\mu_X=\int_{S^B} Xf(X)dX \hspace{0.6cm} e \hspace{0.6cm} \Sigma_X= \int_{S^B} (X- \mu_X)(X- \mu_X)'f(X)dX.} 
   De acordo com Aitchison (1986), Pawlowsky-Glahn e Olea (2004) as integrais 
   são expressas como 
   \deqn{\mu_X=\int_{R^{B-1}} g_1(Z)f(-Z'Z)dZ \hspace{0.6cm} e \hspace{0.6cm}\Sigma_X=\int_{R^{B-1}} g_2(Z)f(-Z'Z)dZ}
   em que \eqn{Z} é a transformação 
   \deqn{Z=\frac{1}{\sqrt{2}}(R')^{-1}(alr(X)-\mu_Y);}
   \eqn{R} é a decomposição Cholesky de \eqn{\Sigma_Y}, uma matriz triangular superior; e as funções \eqn{g_1(Z)} e \eqn{g_2(Z)} são da forma
   \deqn{g_1(Z)=\pi^{-\frac{B-1}{2}} agl(\mu_Y+\sqrt{2}R'Z),} e \cr
   \deqn{g_2(Z)=\pi^{-\frac{B-1}{2}} (agl(\mu_Y+\sqrt{2}R'Z)-\mu_X)(agl(\mu_Y+\sqrt{2}R'Z)-\mu_X)'.}
   Desta forma, as integrais são aproximadas pela integração de Gauss-Hermite multivariada de ordem k:
   \deqn{ \int_{R^{B-1}} g(Z)f(-Z'Z)dZ \approx \sum_{i_1=1}^{k}\sum_{i_2=1}^{k}\cdots\sum_{i_{B-1}=1}^k
   \omega_{i_1}\omega_{i_2}\cdots\omega_{i_{B-1}} g(Z_{i_1},Z_{i_2},...,Z_{i_{B-1}}),
   }
   em que os pesos \eqn{\omega_{i_1}\omega_{i_2}\cdots\omega_{i_{B-1}}} e as abscissas 
   \eqn{Z_{i_1},Z_{i_2},...,Z_{i_{B-1}}} podem ser encontrados, por exemplo, em Abramowitz e Stegun (1992)
   ou calculados usando a função \code{gauss.quad} do pacote \pkg{statmod}. 
}
\value{
  A função retorna uma lista com os seguintes elementos:
  \item{comp1 }{valores esperados preditos dos componentes 1, 2 e 3 no simplex.}
  \item{comp2 }{matriz de covariância predita dos componentes 1, 2 e 3 no simplex.}
}
\references{ 
    Abramowitz, M., and Stegun, I. A., (1972). \emph{Handbook of mathematical functions with
    formulas, graphs, and mathematical tables}. Milton Abramowitz and Irene A. Stegun, Washington.

    Aitchison, J., (1986). \emph{The Statistical analysis of compositional data}. 
    The Blackburn Press, New Jersey.  

    Lark, R. M, and Bishop, T. F. A., (2007). Cokriging particle size fractions of the soil. 
    \emph{European Journal of Soil Science}, june, \bold{58}, 763-774.

    Martins, A. B. T., and Ribeiro Jr, P. J., and Bonat, W. H., (2009). Um modelo geoestatístico para 
    dados composicionais. \emph{Revista Brasileira de Biometria} \bold{27}, n. 3, 456-477.

    Paulino, C. D., and Turkman, M. A. A., and Murteira, B., (2003). \emph{Estatística Bayesiana}.
    Fundação Calouste Gulbenkian, Lisboa.

    Pawlowsky-Glahn, V., and Olea, R. A., (2004). \emph{Geostatistical Analysis of Compositional Data}.
    Oxford University Press, Inc, New York.
}
\author{
  Wagner Hugo Bonat \email{wagner@leg.ufpr.br}, \cr
  Ana Beatriz Tozzo Martins \email{abtmartins@uem.br}, \cr
  Paulo Justiniano Ribeiro Jr. \email{paulojus@leg.ufpr.br}.
}
%\note{ ~~further notes~~ 
% ~Make other sections like Warning with \section{Warning }{....} ~
%}
%\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{
### carregando pacotes
require(geoComp)
require(MASS)
require(statmod)
require(geoR)
### Carregando os dados
data(pivo)
### Selecionando as colunas referentes aos componentes 1, 2 e 3, 
### Coordenada X e coordenada Y
dados <- pivo[,c(6,7,8,1,2)]
### Transformando o objeto "dados" para a classe geoComp
dados <- as.geoComp(dados)
### Construindo a borda da área de predição
bor <- cbind(c(0,seq(0,200,l=100),0),c(0,sqrt(200^2-seq(0,200,l=100)^2),0)) 
### Construindo uma grade de predição
gr <- pred_grid(bor, by=70)
### Ajustando o modelo
estima <- mec(dados)
### Obtendo os valores preditos no R^2
md.cov.ck <- cokrigagem(estima[[1]]$Estimativas, loc=gr,dados.comp=dados)
### Obtendo os valores preditos no simplex por quadratura gaussiana
preditos.gh <- volta.quad(md.cov.ck,n.pontos=6,Variancia=FALSE)
preditos.gh <- data.frame(preditos.gh)
}
\keyword{list}
